@@ -25,23 +25,21 @@ static ISzAlloc allocator = { pmalloc, pfree };
 typedef struct {
     /* Inherits from IByteOut */
     void (*Write)(void *p, Byte b);
-    int (*dst_write)(char *buf, int size);
-    char *buf;
-    int size;
-    int pos;
-} BufferWriter;
+    void (*dst_write)(char *buf, int size, void *userdata);
+    void *userdata;
+} RawWriter;
 
 typedef struct {
     /* Inherits from IByteIn */
     Byte (*Read)(void *p);
     int (*src_readinto)(char *buf, int size, void *userdata);
     void *userdata;
-} BufferReader;
+} RawReader;
 
 void ppmd_state_init(CPpmd7 *ppmd, unsigned int maxOrder, unsigned int memSize);
 void ppmd_state_close(CPpmd7 *ppmd);
-int ppmd_decompress_init(CPpmd7z_RangeDec *rc, BufferReader *reader, int (*src_readingo)(char *, int, void*), void *userdata);
-void ppmd_compress_init(CPpmd7z_RangeEnc *rc, BufferWriter *write);
+int ppmd_decompress_init(CPpmd7z_RangeDec *rc, RawReader *reader, int (*src_readingo)(char *, int, void*), void *userdata);
+void ppmd_compress_init(CPpmd7z_RangeEnc *rc, RawWriter *write, void (*dst_write)(char *, int, void*), void *userdata);
 
 void Ppmd7_Construct(CPpmd7 *p);
 void Ppmd7_Init(CPpmd7 *p, unsigned maxOrder);
